marktools.is_component_with_articulation_attached
=================================================

.. autofunction:: abjad.tools.marktools.is_component_with_articulation_attached.is_component_with_articulation_attached
